PRO MODIS_AVERAGE_AQUA

;$Id: modis_average_aqua.pro,v 1.2 2003/06/06 15:24:25 gumley Exp $

;- Create detector averaged MODIS RSR spectral response data

!p.multi = [0, 4, 4, 0, 0]

;- Get list of RSR data files

list = findfile('../aqua/*.1pct.det')

;- Loop through IR bands

append = 0

for band_index = 1, 36 do begin

  ;- Read the spectral response data
  
  data = ddread(list[band_index - 1])
  
  ;- Extract band number, wavelength (microns), response, and detector
  
  band = long(data[0, 0])
  det  = long(reform(data[1, *]))
  wvn  = double(reform(data[2, *])) * 0.001
  srf  = double(reform(data[3, *]))
  
  ;- Compute wavenumber start and end points for this band

  wvn_min = long(min(10000.0 / wvn) * 10.0D) * 0.1D - 0.05D
  wvn_max = long(max(10000.0 / wvn) * 10.0D) * 0.1D + 0.05D
  
  ;- Create reference arrays

  wvn_del = 0.1D
  npts = (wvn_max - wvn_min) / wvn_del + 1L
  wvn_ref = dindgen(npts) * wvn_del + wvn_min
  srf_ref = dblarr(npts)

  ;- Loop through each detector for this band
  
  ndetectors = 0
  
  for detector = 1, 10 do begin
  
    ;- Get position of good spectral response data for this detector
    
    index = where((det eq detector) and (srf ge 0.01), count)
    if count eq 0 then message, 'Detector not found'
    
    ;- Interpolate the data for this detector
  
    srf_interpolate, wvn[index], srf[index], wvn_interp, srf_interp, $
      /normal, /micron
    
    ;- Add the spectral response data to the reference array
    
    loc1 = long((wvn_interp[0] - wvn_ref[0]) / 0.1D)
    loc2 = loc1 + n_elements(wvn_interp) - 1
    srf_ref[loc1:loc2] = srf_ref[loc1:loc2] + srf_interp

    ;- Increment number of detectors processed
    
    ndetectors = ndetectors + 1
        
  endfor

  ;- Compute the average spectral response
  
  srf_ref = srf_ref / double(ndetectors)

  ;- Extract non-zero response values
  
  pos_index = where(srf_ref ge 0.01, count)
  if count eq 0 then message, 'No non-zero responses found'
  wvn_ref = wvn_ref[pos_index]
  srf_ref = srf_ref[pos_index]
  
  ;- Normalize the response values
  
  srf_max = max(srf_ref)
  srf_ref = srf_ref / srf_max
    
  ;- Write the averaged spectral response data to file
  
  srf_write, 'modis-aqua-avg.srf', 'MODIS', 'AQUA', band, $
    wvn_ref, srf_ref, append=append
  append = 1

  plot, 10000.0 / wvn_ref, srf_ref, title=strcompress(band)
  
  continue:

endfor

!p.multi = 0

END
