PRO MODIS_DET_AQUA

;$Id: modis_det_aqua.pro,v 1.1 2003/06/06 15:23:20 gumley Exp $

;- Create single detector MODIS RSR spectral response data
;- (NOTE: Detector numbers in RSR files are in SBRS order)

;- Set path for Aqua RSR files
path = '../aqua/'

;- Loop over each SBRS detector
for detector = 1, 10 do begin

  ;- Open the output file
  product_detector = 11 - detector
  out_file = string(product_detector, format='("modis-aqua-d", i2.2, ".srf")')
  openw, out_lun, out_file, /get_lun
  printf, out_lun, 'AQUA MODIS SPECTRAL RESPONSE FOR PRODUCT DETECTOR ', $
    string(product_detector, format='(i2.2, 1x, "(LIAM GUMLEY 2003/06/06)")')
    
  ;- Loop over each IR band
  for band = 20, 36 do begin

    ;- Skip band 26
    if (band eq 26) then goto, continue

    ;- Read the spectral response data
    inp_file = path + string(band, format='(i2.2, ".tv.1pct.det")')
    data = ddread(inp_file)

    ;- Extract wavelength (microns), response, and detector
    det  = long(reform(data[1, *]))
    wvn  = double(reform(data[2, *])) * 0.001
    srf  = double(reform(data[3, *]))

    ;- Get position of good spectral response data for this detector
    index = where((det eq detector) and (srf ge 0.01), count)
    if (count eq 0) then message, 'Detector not found'
    
    ;- Interpolate the data for this detector
    srf_interpolate, wvn[index], srf[index], wvn_interp, srf_interp, $
      /normal, /micron
    
    ;- Write the spectral response data to file
    npts = n_elements(wvn_interp)
    printf, out_lun, band, npts, wvn_interp[0], wvn_interp[npts - 1], $
      format='(i3, i5, 2f8.2)'
    printf, out_lun, srf_interp, format='(8f9.6)'

    ;- Skip point
    continue:

  endfor
    
  ;- Close the output file
  free_lun, out_lun

endfor

END
